"use strict";

var _interopRequireWildcard = require("@babel/runtime-corejs3/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

require("core-js/modules/es.function.name");

exports.__esModule = true;
exports.Pane = Pane;

var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));

var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));

var _keys = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/keys"));

var _forEach = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/for-each"));

var _map = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/map"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime-corejs3/helpers/objectWithoutPropertiesLoose"));

var _toPropertyKey2 = _interopRequireDefault(require("@babel/runtime-corejs3/helpers/toPropertyKey"));

var _core = require("@react-leaflet/core");

var _react = _interopRequireWildcard(require("react"));

var DEFAULT_PANES = ['mapPane', 'markerPane', 'overlayPane', 'popupPane', 'shadowPane', 'tilePane', 'tooltipPane'];
var PANE_STYLES = {
  position: 'absolute',
  top: 0,
  right: 0,
  bottom: 0,
  left: 0
};

function omitPane(obj, pane) {
  var _context;

  var _p = obj[pane],
      others = (0, _objectWithoutPropertiesLoose2.default)(obj, (0, _map.default)(_context = [pane]).call(_context, _toPropertyKey2.default));
  return others;
}

function Pane(props) {
  var context = (0, _core.useLeafletContext)();
  var paneElementRef = (0, _react.useRef)(null);
  var propsRef = (0, _react.useRef)(props);

  function applyStyles(paneElement) {
    if (props.className != null) {
      (0, _core.addClassName)(paneElement, props.className);
    }

    if (props.style != null) {
      var _context2;

      (0, _forEach.default)(_context2 = (0, _keys.default)(props.style)).call(_context2, function (key) {
        // @ts-ignore
        paneElement.style[key] = props.style[key];
      });
    }
  }

  function createPane() {
    var name = props.name;

    if ((0, _indexOf.default)(DEFAULT_PANES).call(DEFAULT_PANES, name) !== -1) {
      throw new Error("You must use a unique name for a pane that is not a default Leaflet pane: " + name);
    }

    if ((0, _map.default)(context).getPane(name) != null) {
      throw new Error("A pane with this name already exists: " + name);
    }

    var parentPane = context.pane ? (0, _map.default)(context).getPane(context.pane) : undefined;
    paneElementRef.current = (0, _map.default)(context).createPane(name, parentPane);
    applyStyles(paneElementRef.current);
  }

  function removePane(name) {
    var pane = (0, _map.default)(context).getPane(name);
    pane == null ? void 0 : pane.remove == null ? void 0 : pane.remove(); // @ts-ignore map internals

    if ((0, _map.default)(context)._panes != null) {
      // @ts-ignore map internals
      (0, _map.default)(context)._panes = omitPane((0, _map.default)(context)._panes, name); // @ts-ignore map internals

      (0, _map.default)(context)._paneRenderers = omitPane( // @ts-ignore map internals
      (0, _map.default)(context)._paneRenderers, // @ts-ignore map internals
      name);
    }
  }

  (0, _react.useEffect)(function handlePane() {
    if (paneElementRef.current === null) {
      createPane();
    } else if (props !== propsRef.current) {
      if (props.name === propsRef.current.name) {
        // Remove the previous css class name from the pane if it has changed.
        // setStyle() will take care of adding in the updated className
        if (propsRef.current.className && props.className !== propsRef.current.className) {
          (0, _core.removeClassName)(paneElementRef.current, propsRef.current.className);
        } // Update the pane's DOM node style and class


        applyStyles(paneElementRef.current);
      } else {
        removePane(propsRef.current.name);
        createPane();
      }
    }

    return function removeCreatedPane() {
      removePane(props.name);
    };
  });
  var newContext = (0, _react.useMemo)(function () {
    return (0, _assign.default)({}, context, {
      pane: props.name
    });
  }, [context, props.name]);
  return props.children ? /*#__PURE__*/_react.default.createElement(_core.LeafletProvider, {
    value: newContext
  }, /*#__PURE__*/_react.default.createElement("div", {
    style: PANE_STYLES
  }, props.children)) : null;
}