"use strict";

exports.__esModule = true;
exports.Tooltip = void 0;

var _core = require("@react-leaflet/core");

var _leaflet = require("leaflet");

var _react = require("react");

var Tooltip = (0, _core.createOverlayComponent)(function createTooltip(props, context) {
  return {
    instance: new _leaflet.Tooltip(props, context.overlayContainer),
    context: context
  };
}, function useTooltipLifecycle(element, context, props, setOpen) {
  var onClose = props.onClose,
      onOpen = props.onOpen;
  (0, _react.useEffect)(function addTooltip() {
    var container = context.overlayContainer;

    if (container == null) {
      return;
    }

    var instance = element.instance;

    var onTooltipOpen = function onTooltipOpen(event) {
      if (event.tooltip === instance) {
        instance.update();
        setOpen(true);
        onOpen == null ? void 0 : onOpen();
      }
    };

    var onTooltipClose = function onTooltipClose(event) {
      if (event.tooltip === instance) {
        setOpen(false);
        onClose == null ? void 0 : onClose();
      }
    };

    container.on({
      // @ts-ignore emits TooltipEvent instead of LeafletEvent
      tooltipopen: onTooltipOpen,
      // @ts-ignore emits TooltipEvent instead of LeafletEvent
      tooltipclose: onTooltipClose
    });
    container.bindTooltip(instance);
    return function removeTooltip() {
      container.off({
        // @ts-ignore emits TooltipEvent instead of LeafletEvent
        tooltipopen: onTooltipOpen,
        // @ts-ignore emits TooltipEvent instead of LeafletEvent
        tooltipclose: onTooltipClose
      });
      container.unbindTooltip();
    };
  }, [element, context, setOpen, onClose, onOpen]);
});
exports.Tooltip = Tooltip;