import "core-js/modules/es.function.name";
import _Object$assign from "@babel/runtime-corejs3/core-js-stable/object/assign";
import _indexOfInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/index-of";
import _Object$keys from "@babel/runtime-corejs3/core-js-stable/object/keys";
import _forEachInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/for-each";
import _mapInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/map";
import _objectWithoutPropertiesLoose from "@babel/runtime-corejs3/helpers/esm/objectWithoutPropertiesLoose";
import _toPropertyKey from "@babel/runtime-corejs3/helpers/esm/toPropertyKey";
import { LeafletProvider, addClassName, removeClassName, useLeafletContext } from '@react-leaflet/core';
import React, { useEffect, useMemo, useRef } from 'react';
var DEFAULT_PANES = ['mapPane', 'markerPane', 'overlayPane', 'popupPane', 'shadowPane', 'tilePane', 'tooltipPane'];
var PANE_STYLES = {
  position: 'absolute',
  top: 0,
  right: 0,
  bottom: 0,
  left: 0
};

function omitPane(obj, pane) {
  var _context;

  var _p = obj[pane],
      others = _objectWithoutPropertiesLoose(obj, _mapInstanceProperty(_context = [pane]).call(_context, _toPropertyKey));

  return others;
}

export function Pane(props) {
  var context = useLeafletContext();
  var paneElementRef = useRef(null);
  var propsRef = useRef(props);

  function applyStyles(paneElement) {
    if (props.className != null) {
      addClassName(paneElement, props.className);
    }

    if (props.style != null) {
      var _context2;

      _forEachInstanceProperty(_context2 = _Object$keys(props.style)).call(_context2, function (key) {
        // @ts-ignore
        paneElement.style[key] = props.style[key];
      });
    }
  }

  function createPane() {
    var name = props.name;

    if (_indexOfInstanceProperty(DEFAULT_PANES).call(DEFAULT_PANES, name) !== -1) {
      throw new Error("You must use a unique name for a pane that is not a default Leaflet pane: " + name);
    }

    if (_mapInstanceProperty(context).getPane(name) != null) {
      throw new Error("A pane with this name already exists: " + name);
    }

    var parentPane = context.pane ? _mapInstanceProperty(context).getPane(context.pane) : undefined;
    paneElementRef.current = _mapInstanceProperty(context).createPane(name, parentPane);
    applyStyles(paneElementRef.current);
  }

  function removePane(name) {
    var pane = _mapInstanceProperty(context).getPane(name);

    pane == null ? void 0 : pane.remove == null ? void 0 : pane.remove(); // @ts-ignore map internals

    if (_mapInstanceProperty(context)._panes != null) {
      // @ts-ignore map internals
      _mapInstanceProperty(context)._panes = omitPane(_mapInstanceProperty(context)._panes, name); // @ts-ignore map internals

      _mapInstanceProperty(context)._paneRenderers = omitPane( // @ts-ignore map internals
      _mapInstanceProperty(context)._paneRenderers, // @ts-ignore map internals
      name);
    }
  }

  useEffect(function handlePane() {
    if (paneElementRef.current === null) {
      createPane();
    } else if (props !== propsRef.current) {
      if (props.name === propsRef.current.name) {
        // Remove the previous css class name from the pane if it has changed.
        // setStyle() will take care of adding in the updated className
        if (propsRef.current.className && props.className !== propsRef.current.className) {
          removeClassName(paneElementRef.current, propsRef.current.className);
        } // Update the pane's DOM node style and class


        applyStyles(paneElementRef.current);
      } else {
        removePane(propsRef.current.name);
        createPane();
      }
    }

    return function removeCreatedPane() {
      removePane(props.name);
    };
  });
  var newContext = useMemo(function () {
    return _Object$assign({}, context, {
      pane: props.name
    });
  }, [context, props.name]);
  return props.children ? /*#__PURE__*/React.createElement(LeafletProvider, {
    value: newContext
  }, /*#__PURE__*/React.createElement("div", {
    style: PANE_STYLES
  }, props.children)) : null;
}